==> cscec5b-ecxj-impl-3.0.0-20230403.024840-5-sources.jar: com/ejianc/business/ecxj/vo/SettingSupplierInfoVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;

/**
 * 云筑网供应商实体
 * 
 * @author generator
 * 
 */
public class SettingSupplierInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long productId; // 物资d
    private Long tenderSupplierId; // 云筑供应商Id
    private String tendersNo; // 招标编号
    private String supplierName; // 供应商名称
    private String supplierCreditCode; // 供应商纳税人编号
    private String supplierContractPerson; // 中标供应商联系人
    private String supplierContractPhone; // 中标供应商联系方式
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date createTime; // 创建时间

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public Long getTenderSupplierId() {
        return tenderSupplierId;
    }

    public void setTenderSupplierId(Long tenderSupplierId) {
        this.tenderSupplierId = tenderSupplierId;
    }

    public String getTendersNo() {
        return tendersNo;
    }

    public void setTendersNo(String tendersNo) {
        this.tendersNo = tendersNo;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }

    public String getSupplierContractPerson() {
        return supplierContractPerson;
    }

    public void setSupplierContractPerson(String supplierContractPerson) {
        this.supplierContractPerson = supplierContractPerson;
    }

    public String getSupplierContractPhone() {
        return supplierContractPhone;
    }

    public void setSupplierContractPhone(String supplierContractPhone) {
        this.supplierContractPhone = supplierContractPhone;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20230509.073540-32-sources.jar: com/ejianc/business/ecxj/vo/SettingSupplierInfoVO.java <==
package com.ejianc.business.ecxj.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 云筑网供应商实体
 * 
 * @author generator
 * 
 */
public class SettingSupplierInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long settingId; // 物资d
    private Long tenderSupplierId; // 云筑供应商Id
    private String tendersNo; // 招标编号
    private String supplierName; // 供应商名称
    private String supplierCreditCode; // 供应商纳税人编号
    private String supplierContractPerson; // 中标供应商联系人
    private String supplierContractPhone; // 中标供应商联系方式
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date createTime; // 创建时间

    private List<SettingProductInfoVO> settingProductInfoEntities = new ArrayList<>(); // 设置物资清单实体
    private List<SettingProductInfoVO> noticeProductEntities = new ArrayList<>(); // 设置物资清单实体

    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }

    public Long getTenderSupplierId() {
        return tenderSupplierId;
    }

    public void setTenderSupplierId(Long tenderSupplierId) {
        this.tenderSupplierId = tenderSupplierId;
    }

    public String getTendersNo() {
        return tendersNo;
    }

    public void setTendersNo(String tendersNo) {
        this.tendersNo = tendersNo;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }

    public String getSupplierContractPerson() {
        return supplierContractPerson;
    }

    public void setSupplierContractPerson(String supplierContractPerson) {
        this.supplierContractPerson = supplierContractPerson;
    }

    public String getSupplierContractPhone() {
        return supplierContractPhone;
    }

    public void setSupplierContractPhone(String supplierContractPhone) {
        this.supplierContractPhone = supplierContractPhone;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public List<SettingProductInfoVO> getSettingProductInfoEntities() {
        return settingProductInfoEntities;
    }

    public void setSettingProductInfoEntities(List<SettingProductInfoVO> settingProductInfoEntities) {
        this.settingProductInfoEntities = settingProductInfoEntities;
    }

    public List<SettingProductInfoVO> getNoticeProductEntities() {
        return noticeProductEntities;
    }

    public void setNoticeProductEntities(List<SettingProductInfoVO> noticeProductEntities) {
        this.noticeProductEntities = noticeProductEntities;
    }
}
